// ************************************************************************
//
//   Example of using NamedPipeServer.mqh to receive messages asynchronously
//   from senders, which can be running in a different instance of MT4.
//
//   (For most real-life uses, you would normally use something like the 
//   account number as the server/pipe name.)
//
// ************************************************************************


#include <NamedPipeServer.mqh>


extern string    ServerName = "PipeTest";
extern int       MaxMessagesBetweenTicks = 20;  // See comments in NamedPipeServer.mqh

int init()
{
   if (!IsDllsAllowed()) {
      MessageBox("You need to turn on \'Allow DLL imports\'");
   }
   
   // Create the server
   CreatePipeServer(ServerName, MaxMessagesBetweenTicks);

   return(0);
}

int deinit()
{
   // Destroy the pipe server 
   DestroyPipeServer();
   return(0);
}


int start()
{
   // Log any incoming messages in the Experts tab of the Terminal pane 
   
   // Get the number of messages since the last call to CheckForPipeMessages(),
   // and a string array resized to contain all the messages. (If there have
   // been more than MaxMessagesBetweenTicks messages since the last
   // call to CheckForPipeMessages() - i.e. since the last tick - then
   // the extra messages will have failed and the senders will need to retry.)
   string arrMessages[];
   int MessagesRetrieved = CheckForPipeMessages(arrMessages);
   
   // Write all the messages to the log 
   if (MessagesRetrieved > 0) {
      for (int i = 0; i < MessagesRetrieved; i++) {
         Print("PIPE MESSAGE: " + arrMessages[i]);
      }
   }
   
   return(0);
}

